==> tribune-7.x-3.2.tar.gz: tribune/extra/tribune_pyrolyse/tribune_pyrolyse.js <==
// vim:et:sw=2
(function($) {

Drupal.tribune_pyrolyse = {};

Drupal.behaviors.tribune_pyrolyse = {
  attach: function(context) {
    var push_tribunes = {};

    $('div.tribune-wrapper.tribune-local', context).each(function(index, element) {
      var nid = $(this).attr('data-nid');
      var tribune = Drupal.settings.tribune['tribune-' + nid];

      for (var i in tribune.elements) {
        tribune.elements[i].pyrolyse = {queue: {ids: [], posts: {}}};

        clearInterval(tribune.elements[i].timer);

        var socket = io.connect(tribune.pyrolyse.socket_server);
        socket.on('connect', function(data) {
          Drupal.tribune_pyrolyse.tribune_auth(tribune, socket.socket.sessionid);

          push_tribunes[nid] = true;

          socket.on('tribune-message', function(data) {
            Drupal.tribune_pyrolyse.tribune_new_post(data);
          });
        });
      }
    })

    // This function shouldn't be used for the push tribunes.
    Drupal.tribune_pyrolyse.startReloading = Drupal.tribune.startReloading;
    Drupal.tribune.startReloading = (function() {return function(tribune) {
      var nid = tribune.attr('data-nid');
      if (undefined == push_tribunes[nid]) {
        Drupal.tribune_pyrolyse.startReloading(tribune);
      }
    };})(push_tribunes);
  }
};

Drupal.tribune_pyrolyse.tribune_auth = function(tribune, socket_id) {
  $.post(tribune.pyrolyse.auth_url, {'socket_id': socket_id});
};

Drupal.tribune_pyrolyse.tribune_new_post = function(message) {
  var tribunes = Drupal.settings.tribune['tribune-' + message.data.tribune].elements;
  for (var i in tribunes) {
    var tribune = tribunes[i];

    if (tribune.pyrolyse.timer) {
      clearTimeout(tribune.pyrolyse.timer);
    }

    tribune.pyrolyse.queue.ids.push(message.data.post_id);
    tribune.pyrolyse.queue.posts[message.data.post_id] = message.data.post_html;

    tribune.pyrolyse.timer = setTimeout((function(tribune) {return function() {Drupal.tribune_pyrolyse.insertQueue(tribune);};})(tribune), 250);
  };
};

Drupal.tribune_pyrolyse.insertQueue = function(tribune) {
  var posts = {};

  var ids = tribune.pyrolyse.queue.ids;
  var queued_posts = tribune.pyrolyse.queue.posts;
  tribune.pyrolyse.queue = {ids: [], posts: {}};

  ids.sort();

  for (var i in ids) {
    var id = ids[i];
    posts[id] = queued_posts[id];
  }

  Drupal.tribune.addNewPosts(tribune, posts);
};

})(jQuery);

==> tribune-7.x-3.4.tar.gz: tribune/extra/tribune_pyrolyse/tribune_pyrolyse.js <==
// vim:et:sw=2
(function($) {

Drupal.tribune_pyrolyse = {};

Drupal.behaviors.tribune_pyrolyse = {
  attach: function(context) {
    var push_tribunes = {};

    $('div.tribune-wrapper.tribune-local', context).each(function(index, element) {
      var nid = $(this).attr('data-nid');
      var tribune = Drupal.settings.tribune['tribune-' + nid];

      if (undefined != tribune.pyrolyse) for (var i in tribune.elements) {
        tribune.elements[i].pyrolyse = {queue: {ids: [], posts: {}}};

        clearInterval(tribune.elements[i].timer);

        var socket = io.connect(tribune.pyrolyse.socket_server);
        socket.on('connect', function(data) {
          Drupal.tribune_pyrolyse.tribune_auth(tribune, socket.socket.sessionid);

          push_tribunes[nid] = true;

          socket.on('tribune-message', function(data) {
            Drupal.tribune_pyrolyse.tribune_new_post(data);
          });
        });

        // When we get disconnected, on the subsequent reconnect let's make
        // an AJAX call in case we have missed some messages in between.
        socket.on('disconnect', function(data) {
          socket.on('connect', (function(element) {return function(data) {
            Drupal.tribune_pyrolyse.oldStartReloading(element);
          };})(tribune.elements[i]));
        });
      }
    })
  }
};

Drupal.tribune_pyrolyse.startReloading = function(tribune) {
  var nid = tribune.attr('data-nid');
  if (undefined == Drupal.settings.tribune['tribune-' + nid].pyrolyse) {
    Drupal.tribune_pyrolyse.oldStartReloading(tribune);
  }
};

Drupal.tribune_pyrolyse.oldStartReloading = Drupal.tribune.startReloading;
Drupal.tribune.startReloading = Drupal.tribune_pyrolyse.startReloading;

Drupal.tribune_pyrolyse.tribune_auth = function(tribune, socket_id) {
  $.post(tribune.pyrolyse.auth_url, {'socket_id': socket_id});
};

Drupal.tribune_pyrolyse.tribune_new_post = function(message) {
  var tribunes = Drupal.settings.tribune['tribune-' + message.data.tribune].elements;
  for (var i in tribunes) {
    var tribune = tribunes[i];

    if (tribune.pyrolyse.timer) {
      clearTimeout(tribune.pyrolyse.timer);
    }

    tribune.pyrolyse.queue.ids.push(message.data.post_id);
    tribune.pyrolyse.queue.posts[message.data.post_id] = message.data.post_html;

    tribune.pyrolyse.timer = setTimeout((function(tribune) {return function() {Drupal.tribune_pyrolyse.insertQueue(tribune);};})(tribune), 250);
  };
};

Drupal.tribune_pyrolyse.insertQueue = function(tribune) {
  var posts = {};

  var ids = tribune.pyrolyse.queue.ids;
  var queued_posts = tribune.pyrolyse.queue.posts;
  tribune.pyrolyse.queue = {ids: [], posts: {}};

  ids.sort();

  for (var i in ids) {
    var id = ids[i];
    posts[id] = queued_posts[id];
  }

  Drupal.tribune.addNewPosts(tribune, posts);
};

})(jQuery);
